@@ -1,7 +1,5 @@
-from typing import Any, BinaryIO, Optional
-
-from lxml.html import HTMLParser, fromstring
-from pyquery import PyQuery
+from pathlib import Path
+from typing import Any, Optional, Union
 
 from .model import Ascii2DResponse
 from .network import HandOver
@@ -16,8 +14,8 @@ class Ascii2D(HandOver):
 
     Params Keys
     -----------
-    :param **request_kwargs:   proxies settings.\n
-    :param bovw(boolean):   use ascii2d bovw search, default False \n
+    :param **request_kwargs: proxies and bypass settings.\n
+    :param bovw(bool): use ascii2d bovw search, default False \n
     """
 
     def __init__(self, bovw: bool = False, **request_kwargs: Any):
@@ -25,7 +23,7 @@ class Ascii2D(HandOver):
         self.bovw: bool = bovw
 
     async def search(
-        self, url: Optional[str] = None, file: Optional[BinaryIO] = None
+        self, url: Optional[str] = None, file: Union[str, Path, None] = None
     ) -> Ascii2DResponse:
         """
         Ascii2D
@@ -46,15 +44,18 @@ class Ascii2D(HandOver):
         """
         if url:
             ascii2d_url = "https://ascii2d.net/search/uri"
-            resp = await self.post(ascii2d_url, data={"uri": url})
+            resp_text, resp_url, _ = await self.post(ascii2d_url, data={"uri": url})
         elif file:
             ascii2d_url = "https://ascii2d.net/search/file"
-            resp = await self.post(ascii2d_url, files={"file": file})
+            data = {"file": open(file, "rb")}
+            resp_text, resp_url, _ = await self.post(ascii2d_url, data=data)
         else:
             raise ValueError("url or file is required")
 
         # 如果启用bovw选项，第一次请求是向服务器提交文件
         if self.bovw:
-            resp = await self.get(str(resp.url).replace("/color/", "/bovw/"))
+            resp_text, resp_url, _ = await self.get(
+                resp_url.replace("/color/", "/bovw/")
+            )
 
-        return Ascii2DResponse(resp)
+        return Ascii2DResponse(resp_text, resp_url)
