@@ -1,6 +1,8 @@
-from typing import Any, BinaryIO, Dict, List, Optional, Union
+from json import loads as json_loads
+from pathlib import Path
+from typing import Any, Dict, List, Optional, Union
 
-from httpx import QueryParams
+from multidict import MultiDict
 
 from .model import SauceNAOResponse
 from .network import HandOver
@@ -39,6 +41,7 @@ class SauceNAO(HandOver):
         :param dbs: (list) Search for specific indexes number or all indexes (default=None), see https://saucenao.com/tools/examples/api/index_details.txt
         :param minsim: (int) Control the minimum similarity (default=30)
         :param hide: (int) result hiding control, 0=show all, 1=hide expected explicit, 2=hide expected and suspected explicit, 3=hide all but expected safe. Default is 0.
+        :param **request_kwargs: proxies and bypass settings.
         """
         # minsim 控制最小相似度
         super().__init__(**request_kwargs)
@@ -57,14 +60,14 @@ class SauceNAO(HandOver):
             params["dbmask"] = dbmask
         if dbmaski is not None:
             params["dbmaski"] = dbmaski
-        self.params = QueryParams(params)
+        self.params = MultiDict(params)
         if dbs is not None:
-            self.params = self.params.remove("db")
+            del self.params["db"]
             for i in dbs:
-                self.params = self.params.add("dbs[]", i)
+                self.params.add("dbs[]", i)
 
     async def search(
-        self, url: Optional[str] = None, file: Optional[BinaryIO] = None
+        self, url: Optional[str] = None, file: Union[str, Path, None] = None
     ) -> SauceNAOResponse:
         """
         SauceNAO
@@ -96,18 +99,18 @@ class SauceNAO(HandOver):
         further documentation visit https://saucenao.com/user.php?page=search-api
         """
         params = self.params
-        files = None
+        data = None
         if url:
-            params = params.add("url", url)
+            params.add("url", url)
         elif file:
-            files = {"file": file}
+            data = {"file": open(file, "rb")}
         else:
             raise ValueError("url or file is required")
-        resp = await self.post(
+        resp_text, _, resp_status = await self.post(
             self.url,
             params=params,
-            files=files,
+            data=data,
         )
-        resp_json = resp.json()
-        resp_json.update({"status_code": resp.status_code})
+        resp_json = json_loads(resp_text)
+        resp_json.update({"status_code": resp_status})
         return SauceNAOResponse(resp_json)
